@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.7.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,13 +26,13 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
 #ifndef YY_YY_Y_TAB_H_INCLUDED
 # define YY_YY_Y_TAB_H_INCLUDED
-/* Enabling traces.  */
+/* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
 #endif
@@ -40,45 +40,44 @@
 extern int gmldebug;
 #endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum gmltokentype {
-     GRAPH = 258,
-     NODE = 259,
-     EDGE = 260,
-     DIRECTED = 261,
-     SOURCE = 262,
-     TARGET = 263,
-     XVAL = 264,
-     YVAL = 265,
-     WVAL = 266,
-     HVAL = 267,
-     LABEL = 268,
-     GRAPHICS = 269,
-     LABELGRAPHICS = 270,
-     TYPE = 271,
-     FILL = 272,
-     OUTLINE = 273,
-     OUTLINESTYLE = 274,
-     OUTLINEWIDTH = 275,
-     WIDTH = 276,
-     STYLE = 277,
-     LINE = 278,
-     POINT = 279,
-     TEXT = 280,
-     FONTSIZE = 281,
-     FONTNAME = 282,
-     COLOR = 283,
-     INTEGER = 284,
-     REAL = 285,
-     STRING = 286,
-     ID = 287,
-     NAME = 288,
-     LIST = 289
-   };
+  enum gmltokentype
+  {
+    GRAPH = 258,
+    NODE = 259,
+    EDGE = 260,
+    DIRECTED = 261,
+    SOURCE = 262,
+    TARGET = 263,
+    XVAL = 264,
+    YVAL = 265,
+    WVAL = 266,
+    HVAL = 267,
+    LABEL = 268,
+    GRAPHICS = 269,
+    LABELGRAPHICS = 270,
+    TYPE = 271,
+    FILL = 272,
+    OUTLINE = 273,
+    OUTLINESTYLE = 274,
+    OUTLINEWIDTH = 275,
+    WIDTH = 276,
+    STYLE = 277,
+    LINE = 278,
+    POINT = 279,
+    TEXT = 280,
+    FONTSIZE = 281,
+    FONTNAME = 282,
+    COLOR = 283,
+    INTEGER = 284,
+    REAL = 285,
+    STRING = 286,
+    ID = 287,
+    NAME = 288,
+    LIST = 289
+  };
 #endif
 /* Tokens.  */
 #define GRAPH 258
@@ -114,13 +113,12 @@ extern int gmldebug;
 #define NAME 288
 #define LIST 289
 
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+
+union YYSTYPE
 {
-/* Line 2058 of yacc.c  */
-#line 276 "../../cmd/tools/gmlparse.y"
+#line 276 "../../cmd/tools/gmlparse.y" /* yacc.c:1909  */
 
     int i;
     char *str;
@@ -129,29 +127,17 @@ typedef union YYSTYPE
     gmlattr* ap;
     Dt_t*    list;
 
+#line 131 "y.tab.h" /* yacc.c:1909  */
+};
 
-/* Line 2058 of yacc.c  */
-#line 135 "y.tab.h"
-} YYSTYPE;
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
-# define gmlstype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE gmllval;
 
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int gmlparse (void *YYPARSE_PARAM);
-#else
-int gmlparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
 int gmlparse (void);
-#else
-int gmlparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 #endif /* !YY_YY_Y_TAB_H_INCLUDED  */
