@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.7.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,13 +26,13 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
 #ifndef YY_YY_Y_TAB_H_INCLUDED
 # define YY_YY_Y_TAB_H_INCLUDED
-/* Enabling traces.  */
+/* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
 #endif
@@ -40,24 +40,23 @@
 extern int aagdebug;
 #endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum aagtokentype {
-     T_graph = 258,
-     T_node = 259,
-     T_edge = 260,
-     T_digraph = 261,
-     T_subgraph = 262,
-     T_strict = 263,
-     T_edgeop = 264,
-     T_list = 265,
-     T_attr = 266,
-     T_atom = 267,
-     T_qatom = 268
-   };
+  enum aagtokentype
+  {
+    T_graph = 258,
+    T_node = 259,
+    T_edge = 260,
+    T_digraph = 261,
+    T_subgraph = 262,
+    T_strict = 263,
+    T_edgeop = 264,
+    T_list = 265,
+    T_attr = 266,
+    T_atom = 267,
+    T_qatom = 268
+  };
 #endif
 /* Tokens.  */
 #define T_graph 258
@@ -72,41 +71,28 @@ extern int aagdebug;
 #define T_atom 267
 #define T_qatom 268
 
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+
+union YYSTYPE
 {
-/* Line 2058 of yacc.c  */
-#line 81 "../../lib/cgraph/grammar.y"
+#line 82 "../../lib/cgraph/grammar.y" /* yacc.c:1909  */
 
 			int				i;
 			char			*str;
 			struct Agnode_s	*n;
 
+#line 86 "y.tab.h" /* yacc.c:1909  */
+};
 
-/* Line 2058 of yacc.c  */
-#line 90 "y.tab.h"
-} YYSTYPE;
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
-# define aagstype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE aaglval;
 
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int aagparse (void *YYPARSE_PARAM);
-#else
-int aagparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
 int aagparse (void);
-#else
-int aagparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 #endif /* !YY_YY_Y_TAB_H_INCLUDED  */
